@@ -4,8 +4,8 @@ from ..api import API as BaseAPI
 from ..api import register_api
 
 with contextlib.suppress(ImportError):
-    from nonebot.adapters.telegram import Adapter
+    from nonebot.adapters.telegram import Adapter, Bot, Event
 
     @register_api(Adapter)
-    class API(BaseAPI):
-        pass
+    class API(BaseAPI[Bot, Event]):
+        pass  # wtf
